Summary: The Squid proxy caching server.
Name: squid
Version: 2.4.STABLE7
Release: 1tr
License: GPL
Group: Network/Services
Source: http://www.squid-cache.org/Versions/v2/2.4/squid-%{version}-src.tar.gz
Source2: squid.init
Source3: squid.logrotate
Patch1: squid-2.4-config.patch
Patch2: squid-2.4-iconpath.patch
BuildRoot: /var/tmp/%{name}-root
Prereq: chkconfig logrotate shadow-utils tsl-utils
BuildRequires: perl
Obsoletes: squid-novm

%description
Squid is a high-performance proxy caching server for Web clients,
supporting FTP, gopher, and HTTP data objects. Unlike traditional
caching software, Squid handles all requests in a single,
non-blocking, I/O-driven process. Squid keeps meta data and especially
hot objects cached in RAM, caches DNS lookups, supports non-blocking
DNS lookups, and implements negative caching of failed requests.

Squid consists of a main server program squid, a program for retrieving
FTP data (ftpget), and some management and client tools.

Install squid if you need a proxy caching server.

%prep
%setup -q
%patch1 -p1 -b .config
%patch2 -p1 -b .iconpath

# Fix path
perl -pi -e 's/\/usr\/local\/bin\/perl/\/usr\/bin\/perl/' `find . -type f`

%build
CFLAGS="$RPM_OPT_FLAGS" ./configure --prefix=/usr \
   --exec_prefix=/usr --bindir=/usr/sbin --libexecdir=/usr/lib/squid \
   --localstatedir=/var/spool/squid --sysconfdir=/etc/squid --enable-async-io \
   --enable-poll --mandir='${prefix}/share/man' # --enable-icmp
   
# Some versions of autoconf fail to detect sys/resource.h correctly;
# apparently because it generates a compiler warning.

if [ -e /usr/include/sys/resource.h ]; then
cat >>include/autoconf.h <<EOF
#ifndef HAVE_SYS_RESOURCE_H
#define HAVE_SYS_RESOURCE_H 1
#define HAVE_STRUCT_RUSAGE 1
#endif
EOF
fi

export logdir=/var/log/squid
export libexecdir=/usr/lib/squid
export sysconfdir=/etc/squid

DEFAULTS="DEFAULT_CACHE_LOG=${logdir}/cache.log \
          DEFAULT_ACCESS_LOG=${logdir}/access.log \
          DEFAULT_STORE_LOG=${logdir}/store.log \
          DEFAULT_PID_FILE=/var/run/squid.pid \
          DEFAULT_SWAP_DIR=/var/spool/squid \
          DEFAULT_ICON_DIR=${libexecdir}/icons \
          DEFAULT_ERROR_DIR=${libexecdir}/errors/English \
          DEFAULT_MIME_TABLE=${libexecdir}/mime.conf \
          DEFAULT_MIB_PATH=/usr/lib/squid/mib.txt"

make ${DEFAULTS} -f makefile

%install
rm -rf $RPM_BUILD_ROOT
make install  \
	prefix=$RPM_BUILD_ROOT/usr \
	sysconfdir=$RPM_BUILD_ROOT/etc/squid \
	localstatedir=$RPM_BUILD_ROOT/var/spool/squid \
	bindir=$RPM_BUILD_ROOT/usr/sbin \
	libexecdir=$RPM_BUILD_ROOT/usr/lib/squid
#install -m 4750 src/pinger $RPM_BUILD_ROOT/usr/lib/squid

cd errors
rm -rf $RPM_BUILD_ROOT/etc/squid/errors
mkdir -p $RPM_BUILD_ROOT/usr/lib/squid/errors
for i in *; do
   if [ -d $i ]; then
       mkdir -p $RPM_BUILD_ROOT/usr/lib/squid/errors/$i
       install -m 644 $i/* $RPM_BUILD_ROOT/usr/lib/squid/errors/$i
   fi
done
ln -s /usr/lib/squid/errors/English $RPM_BUILD_ROOT/etc/squid/errors

mkdir -p $RPM_BUILD_ROOT/etc/rc.d/init.d
mkdir -p $RPM_BUILD_ROOT/etc/logrotate.d
install -m 755 $RPM_SOURCE_DIR/squid.init $RPM_BUILD_ROOT/etc/rc.d/init.d/squid
install -m 644 $RPM_SOURCE_DIR/squid.logrotate $RPM_BUILD_ROOT/etc/logrotate.d/squid

mkdir -p $RPM_BUILD_ROOT/var/log/squid
mkdir -p $RPM_BUILD_ROOT/var/spool/squid

strip $RPM_BUILD_ROOT/usr/sbin/* \
      $RPM_BUILD_ROOT/usr/lib/squid/* || :

ln -s /etc/squid/mime.conf $RPM_BUILD_ROOT/usr/lib/squid/mime.conf

%pre
/usr/sbin/useradd -u 23 -d /var/spool/squid -r -s /dev/null squid >/dev/null 2>&1
/usr/sbin/groupadd -g 23 -r -f squid >/dev/null 2>&1

for i in /var/{log/squid,spool/squid} ; do
	if [ -d $i ] ; then
		for adir in `find $i -maxdepth 0 \! -user squid`; do
			chown -R squid.squid $adir
		done
	fi
done

exit 0

%post
if [ $1 = 0 ]; then
 case "$LANG" in
  bg*)
     DIR=Bulgarian
     ;;
  cs*)
     DIR=Czech
     ;;
  da*)
     DIR=Danish
     ;;
  nl*)
     DIR=Dutch
     ;;
  en*)
     DIR=English
     ;;
  ea*)
     DIR=Estonian
     ;;
  fi*)
     DIR=Finnish
     ;;
  fr*)
     DIR=French
     ;;
  de*)
     DIR=German
     ;;
  hu*)
     DIR=Hungarian
     ;;
  it*)
     DIR=Italian
     ;;
  ja*)
     DIR=Japanese
     ;;
  kr*)
     DIR=Korean
     ;;
  pl*)
     DIR=Polish
     ;;
  pt*)
     DIR=Portuguese
     ;;
  ro*)
     DIR=Romanian
     ;;
  ru*)
     DIR=Russian-koi8-r
     ;;
  sk*)
     DIR=Slovak
     ;;
  es*)
     DIR=Spanish
     ;;
  sv*)
     DIR=Swedish
     ;;
  zh*)
     DIR=Traditional_Chinese
     ;;
  tr*)
     DIR=Turkish
     ;;
  *)
     DIR=English
     ;;
 esac
 ln -snf /usr/lib/squid/errors/$DIR /etc/squid/errors
fi
# Restart service after upgrade.
/sbin/restart_maybe squid

%preun
if [ $1 = 0 ] ; then
	rm -f /var/log/squid/*
	/sbin/chkconfig --del squid
	%{_initdir}/squid stop || :
fi

%postun
if [ $1 = 0 ] ; then
	userdel squid
	groupdel squid
fi

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%config(noreplace) /etc/squid/squid.conf
%config(noreplace) /etc/squid/mime.conf
%config(noreplace) /etc/squid/mib.txt
/etc/squid/errors
/usr/lib/squid/errors
/usr/lib/squid/icons
/usr/lib/squid/mime.conf
# /usr/lib/squid/dnsserver
/usr/lib/squid/unlinkd
#%attr(4750,root,squid) /usr/lib/squid/pinger
/usr/sbin/squid
/usr/sbin/client
/usr/lib/squid/cachemgr.cgi
%config(noreplace) /etc/rc.d/init.d/squid
%config(noreplace) /etc/logrotate.d/squid
%doc README ChangeLog QUICKSTART doc/*
%doc contrib/url-normalizer.pl contrib/rredir.* contrib/user-agents.pl
%doc src/*.conf
%attr(750,squid,root) %dir /var/log/squid
%attr(750,squid,root) %dir /var/spool/squid

%changelog
* Wed Jul 04 2002 Nico Erfurth <masta@trustix.org> 2.4.STABLE7-1tr
- Upgraded to 2.4.STABLE7, includes security fixes
- Some spec cleanups.

* Wed Mar 27 2002 Christian H. Toldnes <christht@trustix.com>
- Picked up 2.4.STABLE6 which is a security fix.

* Fri Feb 22 2002 Erlend Midttun <erlendbm@trustix.com>
- Updated to 2.4.STABLE4 to fix security holes.

* Wed Aug 15 2001 Oystein Viggen <oysteivi@trustix.com>
- Fixed wrong cachedir in default config.

* Fri Apr 20 2001 Erlend Midttun <erlendbm@trustix.com>
- Fixed path to perl in support programs.

* Tue Apr 17 2001 Erlend Midttun <erlendbm@trustix.com>
- Updated to 2.4.STABLE1
- Added bugfix-patches up to current.

* Fri Jan 12 2001 Oystein Viggen <oysteivi@trustix.com>
- Added a patch for insecure tempfiles

* Wed Sep 13 2000 Per Ivar Paulsen <perp@trustix.com>
- Picked up STABLE4

* Fri Jun 23 2000 Erlend Midttun <erlendbm@trustix.com>
- Fixed some group problems

* Wed May  3 2000 Erlend Midttun <erlendbm@trustix.com>
- Upgraded to version STABLE2

* Fri Feb 25 2000 Lars Gaarden <larsg@trustix.com>
- Changed group ownership on /var/log/squid and /var/spool/squid

* Tue Jan 25 2000 Per Ivar Paulsen <perp@trustix.com>
- Initial release for the Trustix Secure Linux distribution.
- Added noreplace.
- Moved man and info pages to /usr/share adhering to FHS
- TODO: add better default configuration

* Mon Jan 10 2000 Bill Nottingham <notting@redhat.com>
- 2.3.STABLE1 (whee, another serial number)

* Tue Dec 21 1999 Bernhard Rosenkraenzer <bero@redhat.com>
- Fix compliance with ftp RFCs
  (http://www.wu-ftpd.org/broken-clients.html)
- Work around a bug in some versions of autoconf
- BuildPrereq sgml-tools - we're using sgml2html

* Mon Oct 18 1999 Bill Nottingham <notting@redhat.com>
- add a couple of bugfix patches

* Wed Oct 13 1999 Bill Nottingham <notting@redhat.com>
- update to 2.2.STABLE5.
- update FAQ, fix URLs.

* Sat Sep 11 1999 Cristian Gafton <gafton@redhat.com>
- transform restart in reload and add restart to the init script

* Tue Aug 31 1999 Bill Nottingham <notting@redhat.com>
- add squid user as user 23.

* Mon Aug 16 1999 Bill Nottingham <notting@redhat.com>
- initscript munging
- fix conflict between logrotate & squid -k (#4562)

* Wed Jul 28 1999 Bill Nottingham <notting@redhat.com>
- put cachemgr.cgi back in /usr/lib/squid

* Wed Jul 14 1999 Bill Nottingham <notting@redhat.com>
- add webdav bugfix patch (#4027)

* Mon Jul 12 1999 Bill Nottingham <notting@redhat.com>
- fix path to config in squid.init (confuses linuxconf)

* Wed Jul  7 1999 Bill Nottingham <notting@redhat.com>
- 2.2.STABLE4

* Wed Jun 9 1999 Dale Lovelace <dale@redhat.com>
- logrotate changes
- errors from find when /var/spool/squid or
- /var/log/squid didn't exist

* Thu May 20 1999 Bill Nottingham <notting@redhat.com>
- 2.2.STABLE3

* Thu Apr 22 1999 Bill Nottingham <notting@redhat.com>
- update to 2.2.STABLE.2

* Sun Apr 18 1999 Bill Nottingham <notting@redhat.com>
- update to 2.2.STABLE1

* Thu Apr 15 1999 Bill Nottingham <notting@redhat.com>
- don't need to run groupdel on remove
- fix useradd

* Mon Apr 12 1999 Bill Nottingham <notting@redhat.com>
- fix effective_user (bug #2124)

* Mon Apr  5 1999 Bill Nottingham <notting@redhat.com>
- strip binaries

* Thu Apr  1 1999 Bill Nottingham <notting@redhat.com>
- duh. adduser does require a user name.
- add a serial number

* Tue Mar 30 1999 Bill Nottingham <notting@redhat.com>
- add an adduser in %pre, too

* Thu Mar 25 1999 Bill Nottingham <notting@redhat.com>
- oog. chkconfig must be in %preun, not %postun

* Wed Mar 24 1999 Bill Nottingham <notting@redhat.com>
- switch to using group squid
- turn off icmp (insecure)
- update to 2.2.DEVEL3
- build FAQ docs from source

* Tue Mar 23 1999 Bill Nottingham <notting@redhat.com>
- logrotate changes

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com> 
- auto rebuild in the new build environment (release 4)

* Wed Feb 10 1999 Bill Nottingham <notting@redhat.com>
- update to 2.2.PRE2

* Wed Dec 30 1998 Bill Nottingham <notting@redhat.com>
- cache & log dirs shouldn't be world readable
- remove preun script (leave logs & cache @ uninstall)

* Tue Dec 29 1998 Bill Nottingham <notting@redhat.com>
- fix initscript to get cache_dir correct

* Fri Dec 18 1998 Bill Nottingham <notting@redhat.com>
- update to 2.1.PATCH2
- merge in some changes from RHCN version

* Sat Oct 10 1998 Cristian Gafton <gafton@redhat.com>
- strip binaries
- version 1.1.22

* Sun May 10 1998 Cristian Gafton <gafton@redhat.com>
- don't make packages conflict with each other...

* Sat May 02 1998 Cristian Gafton <gafton@redhat.com>
- added a proxy auth patch from Alex deVries <adevries@engsoc.carleton.ca>
- fixed initscripts

* Thu Apr 09 1998 Cristian Gafton <gafton@redhat.com>
- rebuilt for Manhattan

* Fri Mar 20 1998 Cristian Gafton <gafton@redhat.com>
- upgraded to 1.1.21/1.NOVM.21

* Mon Mar 02 1998 Cristian Gafton <gafton@redhat.com>
- updated the init script to use reconfigure option to restart squid instead
  of shutdown/restart (both safer and quicker)

* Sat Feb 07 1998 Cristian Gafton <gafton@redhat.com>
- upgraded to 1.1.20
- added the NOVM package and tryied to reduce the mess in the spec file

* Wed Jan 7 1998 Cristian Gafton <gafton@redhat.com>
- first build against glibc
- patched out the use of setresuid(), which is available only on kernels
  2.1.44 and later

